@@ -2,4 +2,4 @@ from gitback import backup
 from os import rmdir
 if __name__ == '__main__':
     try: backup()
-    except: rmdir("backup")
\ No newline at end of file
+    except Exception: rmdir("backup")
\ No newline at end of file
